# Amplitude

Amplitude commands are used to create arbitrary time or frequency variations of load, displacement, and some interaction attributes throughout a step using step time or throughout an analysis using total time.

## Create amplitudes

### In Mdb

```{eval-rst}
.. autoclass:: abaqus.Amplitude.AmplitudeModel.AmplitudeModel
    :members:
    :show-inheritance:

    .. autoclasstoc::

```

### In Odb

```{eval-rst}
.. autoclass:: abaqus.Amplitude.AmplitudeOdb.AmplitudeOdb
    :members:
    :show-inheritance:

    .. autoclasstoc::

```

## Other Classes

```{eval-rst}

.. toggle::

    .. automembers:: abaqus.Amplitude
        :recursive:
        :exclude: AmplitudeModel, AmplitudeOdb

    .. placeholder for empty members
```
